.. QCRAFT AutoScheduler documentation master file, created by
   sphinx-quickstart on Mon Jul 15 10:21:45 2024.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

QCRAFT AutoScheduler |release| documentation
===========================================

QCRAFT-AutoScheduler is part of the Quantum Circuit Research And Framework Toolbox (QCRAFT) project, developed by SPILab at the University of Extremadura.
With this library we aim to provide a tool that allows users to improve the efficiency of their quantum tasks.

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   introduction
   installation
   usage
   api_reference
   changelog

